% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/DAR_function.R
\name{DAR.test}
\alias{DAR.test}
\title{Bootstrap-assisted spectra-based test for diagnostic checking for FAR(1) models}
\usage{
DAR.test(X, bsize = "auto", M = 500, nbasis = 20, P = 50)
}
\arguments{
\item{X:}{R times N matrix, where N is the sample size and R is the number of observations for each curve.}

\item{bsize:}{Block size in the block bootstrap method. If bsize is "auto", the minimal volatility method is used to select the block size.}

\item{M:}{Number of bootstrap replications.}

\item{nbasis:}{Number of B-spline basis functions.}

\item{P:}{Number of pieces used to approximate integrals using the Riemann sums.}
}
\value{
P-value and whether the test is rejected at the nominal levels 10\%, 5\%, and 1\%.
}
\description{
Bootstrap-assisted spectra-based test for diagnostic checking for FAR(1) models
}
\examples{
# A small simulation study
# The number of replications is 100
# Generate "discrete" FAR(1) process with the Gaussian kernel and Brownian motion errors

Psi <- matrix(0,1001,1001)
for(i in 0:1000)
{
t <- i/1000
s <- (0:1000)/1000
Psi[i+1,] <- 1/1.462652/2*exp((t^2+s^2)/2)
}

AR<-function(N)
{
xr <- matrix(rnorm(1000*(N+30)),1000,(N+30))
xr <- rbind(0,xr)
BM <- apply(xr,2,cumsum)/sqrt(1000)
AR <- matrix(0,1001,(N+30))
AR[,1] <- BM[,1]
for(i in 1:(N+29))
 {
 AR[,i+1] <- (1/1000)*Psi\%*\%AR[,i]+BM[,i+1]
 }
return(AR[,31:(N+30)])
}

set.seed(3)
N <- 101
rej <- matrix(NA,100,3)
for(i in 1:100)
{
X <- AR(N)
rej[i,] <- DAR.test(X=X, bsize=1, M=299)[[1]]
if(i\%\%10==0) print(i)
}
erej <- apply(rej,2,mean)
erej
}

