% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/WN_function.R
\name{WN.test}
\alias{WN.test}
\title{Bootstrap-assisted spectra-based test for white noise testing}
\usage{
WN.test(X, bsize = "auto", M = 500, nbasis = 20, P = 50)
}
\arguments{
\item{X:}{R times N matrix, where N is the sample size and R is the number of observations for each curve.}

\item{bsize:}{Block size in the block bootstrap method. If bsize is "auto", the minimal volatility method is used to select the block size.}

\item{M:}{Number of bootstrap replications.}

\item{nbasis:}{Number of B-spline basis functions.}

\item{P:}{Number of pieces used to approximate integrals using the Riemann sums.}
}
\value{
P-value and whether the test is rejected at the nominal levels 10\%, 5\%, and 1\%.
}
\description{
Bootstrap-assisted spectra-based test for white noise testing
}
\examples{
# A small simulation study
# The data are i.i.d Brownian motions
# The number of replications is 100
# The sample size is 101

set.seed(3)
N <- 101
rej <- matrix(NA,100,3)
for(i in 1:100)
{
xr <- matrix(rnorm(1000*N,0,1),1000,N)
xr <- rbind(0,xr)
BM <- apply(xr,2,cumsum)/sqrt(1000)
rej[i,] <- WN.test(X=BM, bsize=1, M=299)[[1]]
if(i\%\%10==0) print(i)
}
erej <- apply(rej,2,mean)
erej
}

